@@ -256,7 +256,7 @@ setMethod("summary", "H2OModel", function(object, ...) {
   if( !is.null(tm$Gini)                                            )  cat("\nGini: (Extract with `h2o.gini`)", tm$Gini)
   if( !is.null(tm$null_deviance)                                   )  cat("\nNull Deviance: (Extract with `h2o.nulldeviance`)", tm$null_deviance)
   if( !is.null(tm$residual_deviance)                               )  cat("\nResidual Deviance: (Extract with `h2o.residual_deviance`)", tm$residual_deviance)
-  if(!is.null(o@algorithm) && o@algorithm %in% c("glm","gbm","drf","xgboost","generic")) {
+  if(!is.null(o@algorithm) && o@algorithm %in% c("gam","glm","gbm","drf","xgboost","generic")) {
     if( !is.null(tm$r2) && !is.na(tm$r2)                           )  cat("\nR^2: (Extract with `h2o.r2`)", tm$r2)
   }
   if( !is.null(tm$AIC)                                             )  cat("\nAIC: (Extract with `h2o.aic`)", tm$AIC)
@@ -596,7 +596,7 @@ setMethod("show", "H2OBinomialMetrics", function(object) {
     cat("AUC:  ", object@metrics$AUC, "\n", sep="")
     cat("AUCPR:  ", object@metrics$pr_auc, "\n", sep="")
     cat("Gini:  ", object@metrics$Gini, "\n", sep="")
-    if(!is.null(object@algorithm) && object@algorithm %in% c("glm","gbm","drf","xgboost","generic")) {
+    if(!is.null(object@algorithm) && object@algorithm %in% c("gam","glm","gbm","drf","xgboost","generic")) {
 
       if (!is.null(object@metrics$r2) && !is.na(object@metrics$r2)) cat("R^2:  ", object@metrics$r2, "\n", sep="")
       if (!is.null(object@metrics$null_deviance0)) cat("Null Deviance:  ", object@metrics$null_deviance,"\n", sep="")
@@ -688,7 +688,7 @@ setMethod("show", "H2ORegressionMetrics", function(object) {
   } else {
       cat("Mean Residual Deviance :  ", h2o.mean_residual_deviance(object), "\n", sep="")
   }
-  if(!is.null(object@algorithm) && object@algorithm %in% c("glm","gbm","drf","xgboost","generic") && exists("r2", where=object@metrics)) {
+  if(!is.null(object@algorithm) && object@algorithm %in% c("gam","glm","generic") && exists("r2", where=object@metrics)) {
     if (!is.na(h2o.r2(object))) cat("R^2 :  ", h2o.r2(object), "\n", sep="")
     null_dev <- h2o.null_deviance(object)
     res_dev  <- h2o.residual_deviance(object)
@@ -780,6 +780,22 @@ setClass("H2OTargetEncoderMetrics", contains="H2OModelMetrics")
 #' @export
 setClass("H2OModelFuture", representation(job_key="character", model_id="character"))
 
+#' H2O Future Segment Models
+#'
+#' A class to contain the information for background segment models jobs.
+#' @slot job_key a character key representing the identification of the job process.
+#' @slot segment_models_id the final identifier for the segment models collections
+#' @seealso \linkS4class{H2OSegmentModels} for the final segment models types.
+#' @export
+setClass("H2OSegmentModelsFuture", representation(job_key="character", segment_models_id="character"))
+
+#' H2O Segment Models
+#'
+#' A class to contain the information for segment models.
+#' @slot segment_models_id the  identifier for the segment models collections
+#' @export
+setClass("H2OSegmentModels", representation(segment_models_id="character"))
+
 #' H2O Grid
 #'
 #' A class to contain the information about grid results
@@ -805,6 +821,9 @@ setClass("H2OGrid", representation(grid_id = "character",
                                    failed_raw_params = "matrix",
                                    summary_table = "ANY"))
 
+#' @rdname h2o.keyof
+setMethod("h2o.keyof", signature("H2OGrid"), function(object) object@grid_id)
+
 #' Format grid object in user-friendly way
 #'
 #' @rdname H2OGrid-class
