@@ -99,6 +99,14 @@ h2o.removeAll <- function(timeout_secs=0, retained_elements = c()) {
 #' @param ids The object or hex key associated with the object to be removed or a vector/list of those things.
 #' @param cascade Boolean, if set to TRUE (default), the object dependencies (e.g. submodels) are also removed.
 #' @seealso \code{\link{h2o.assign}}, \code{\link{h2o.ls}}
+#' @examples 
+#' \dontrun{
+#' library(h2o)
+#' h2o.init()
+#' iris_hex <- as.h2o(iris)
+#' model <- h2o.glm(1:4,5,training = iris_hex, family = "multinomial")
+#' h2o.rm(iris_hex)
+#' }
 #' @export
 h2o.rm <- function(ids, cascade=TRUE) {
   gc()
@@ -129,6 +137,32 @@ h2o.rm <- function(ids, cascade=TRUE) {
 #' Get the reference to a frame with the given id in the H2O instance.
 #'
 #' @param id A string indicating the unique frame of the dataset to retrieve.
+#' @examples 
+#' \dontrun{
+#' library(h2o)
+#' h2o.init()
+#' 
+#' f <- "http://h2o-public-test-data.s3.amazonaws.com/smalldata/iris/iris_train.csv"
+#' train <- h2o.importFile(f)
+#' y <- "species"
+#' x <- setdiff(names(train), y)
+#' train[,y] <- as.factor(train[,y])
+#' nfolds <- 5
+#' num_base_models <- 2
+#' my_gbm <- h2o.gbm(x = x, y = y, training_frame = train, 
+#'                   distribution = "multinomial", ntrees = 10, 
+#'                   max_depth = 3, min_rows = 2, learn_rate = 0.2, 
+#'                   nfolds = nfolds, fold_assignment = "Modulo", 
+#'                   keep_cross_validation_predictions = TRUE, seed = 1)
+#' my_rf <- h2o.randomForest(x = x, y = y, training_frame = train, 
+#'                           ntrees = 50, nfolds = nfolds, fold_assignment = "Modulo", 
+#'                           keep_cross_validation_predictions = TRUE, seed = 1)
+#' stack <- h2o.stackedEnsemble(x = x, y = y, training_frame = train, 
+#'                              model_id = "my_ensemble_l1", 
+#'                              base_models = list(my_gbm@model_id, my_rf@model_id), 
+#'                              keep_levelone_frame = TRUE)
+#' h2o.getFrame(stack@model$levelone_frame_id$name)
+#' }
 #' @export
 h2o.getFrame <- function(id) {
   fr <- .newH2OFrame(id,id,-1,-1)
@@ -210,6 +244,11 @@ h2o.getModel <- function(model_id) {
     }
   })
 
+  # Run model specific hooks
+  model_fill_func <- paste0(".h2o.fill_", json$algo)
+  if (exists(model_fill_func, mode="function")) {
+    model <- do.call(model_fill_func, list(model, parameters, allparams))
+  }
 
   # Convert ignored_columns/response_column to valid R x/y
 
@@ -248,6 +287,50 @@ h2o.getModel <- function(model_id) {
   }
 }
 
+#' Retrieves an instance of \linkS4class{H2OSegmentModels} for a given id.
+#'
+#' @param segment_models_id A string indicating the unique segment_models_id
+#         of the collections of segment-models to retrieve.
+#' @return Returns an object that is a subclass of \linkS4class{H2OSegmentModels}.
+#' @examples
+#' \dontrun{
+#' library(h2o)
+#' h2o.init()
+#' iris_hf <- as.h2o(iris)
+#' h2o.train_segments(algorithm = "gbm",
+#'                    segment_columns = "Species", segment_models_id="models_by_species",
+#'                    x = c(1:3), y = 4, training_frame = iris_hf, ntrees = 5, max_depth = 4)
+#' models <- h2o.get_segment_models("models_by_species")
+#' as.data.frame(models)
+#' }
+#' @export
+h2o.get_segment_models <- function(segment_models_id) {
+  new("H2OSegmentModels", segment_models_id=segment_models_id)
+}
+
+#' Converts a collection of Segment Models to a data.frame
+#'
+#' @param x Object of class \linkS4class{H2OSegmentModels}.
+#' @param ... Further arguments to be passed down from other methods.
+#' @return Returns data.frame with result of segment model training.
+#' @examples
+#' \dontrun{
+#' library(h2o)
+#' h2o.init()
+#' iris_hf <- as.h2o(iris)
+#' models <- h2o.train_segments(algorithm = "gbm",
+#'                              segment_columns = "Species",
+#'                              x = c(1:3), y = 4,
+#'                              training_frame = iris_hf,
+#'                              ntrees = 5,
+#'                              max_depth = 4)
+#' as.data.frame(models)
+#' }
+#' @export
+as.data.frame.H2OSegmentModels <- function(x, ...) {
+  as.data.frame(.newExpr("segment_models_as_frame", x@segment_models_id))
+}
+
 #'
 #' Download the Scoring POJO (Plain Old Java Object) of an H2O Model
 #'
@@ -409,6 +492,7 @@ h2o.download_mojo <- function(model, path=getwd(), get_genmodel_jar=FALSE, genmo
 
 #'
 #' Download the model in binary format.
+#' The owner of the file saved is the user by which python session was executed.
 #'
 #' @param model An H2OModel
 #' @param path The path where binary file should be downloaded. Downloaded to current directory by default.
